Macros
- assert_
impl_ one - Asserts that the type implements exactly one in a set of traits.
- builder_
helper - 为构建器模式提供辅助方法的宏。
- const_
assert - Asserts that constant expressions evaluate to
true. - register_
factory - 为产品类型注册工厂实现的宏。
- submit
- Enter an element into the plugin registry corresponding to its type.
Structs
- Factory
Registry - 工厂实现的注册表条目。
- Observer
Registry - 观察者注册表
- Simple
Factory - 用于创建类型
T实例的工厂集合。
Enums
- Factory
Error - 通过工厂创建对象时可能发生的错误。
- Factory
Fallback - 当找不到指定 ID 的工厂时的处理策略。
- Notify
Strategy - 通知策略
Traits
- Factory
- 用于创建类型
T实例的工厂 trait。 - Observable
- 被观察者 trait
- Observer
- 观察者 trait